#include <iostream>
#include <vector>
#include <string>
#include <svg.h>

using namespace std;

void
svg_begin(double width, double height) {
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    cout << "<svg ";
    cout << "width='" << width << "' ";
    cout << "height='" << height << "' ";
    cout << "viewBox='0 0 " << width << " " << height << "' ";
    cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void
svg_end() {
    cout << "</svg>\n";
}

void
svg_text(double left, double baseline, string text) {
    cout << "<text x='"<< left << "' y='"<< baseline <<"'        > "<< text <<" </text>";
}

void
svg_rect(double x, double y, double width, double height){
    cout << "<rect x='"<<x<<"' y='"<<y<<"' width='"<<width<<"' height='"<<height<<"' stroke ='cyan' fill='#fce166' />\n";
}

void
svg_procent(double left_procent, double baseline, string text) {
    cout << "<text x='"<< left_procent << "' y='"<< baseline << "'> "<< text <<"% </text>";
}

void
show_histogram_svg(const vector<size_t>& bins, const vector<size_t>& procent) {
    const auto IMAGE_WIDTH = 400;
    const auto IMAGE_HEIGHT = 300;
    const auto TEXT_LEFT = 20;
    const auto TEXT_BASELINE = 20;
    const auto TEXT_WIDTH = 50;
    const auto BIN_HEIGHT = 30;
    const auto BLOCK_WIDTH = 10;

    const double SCALE = IMAGE_WIDTH - TEXT_WIDTH;
    svg_begin(800, 300);


    double max_count = 0;
    for (double x: bins) {
        if (x > max_count) {
                max_count = x;
        }
    }

    double top = 0;
    if ((max_count*BLOCK_WIDTH)>SCALE){
    for (size_t i = 0; i < bins.size(); i++) {
        const double bin_width = SCALE * ( bins[i] / max_count);
        const auto TEXT_LEFT_PROCENT = SCALE+TEXT_WIDTH+20;
        svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bins[i]));
        svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT);
        svg_procent(TEXT_LEFT_PROCENT, top + TEXT_BASELINE, to_string(procent[i]));
        top += BIN_HEIGHT;
        cout << endl;
        cout << bin_width;
    }
    }
    else{
        for (size_t i = 0; i < bins.size(); i++) {
        const double bin_width = BLOCK_WIDTH * bins[i];
        const auto TEXT_LEFT_PROCENT = (max_count * BLOCK_WIDTH)+TEXT_WIDTH+20;
        svg_text(TEXT_LEFT, top + TEXT_BASELINE, to_string(bins[i]));
        svg_rect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT);
        svg_procent(TEXT_LEFT_PROCENT, top + TEXT_BASELINE, to_string(procent[i]));
        top += BIN_HEIGHT;
        cout << endl;
        cout << bin_width;
}
    }
    svg_end();

}


